"use strict";
/**
 * Javascript ALSA aplay wrapper for Node.js
 *
 * @mantainedBy Rocco Musolino - @roccomuso
 * @author Patrik Melander (lotAballs) node-aplay module
 * @originalAuthor Maciej Sopyło @ KILLAHFORGE.
 *
 * Dependencies: sudo apt-get install alsa-base alsa-utils
 * MIT License
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var os = require("os");
var child_process_1 = require("child_process");
var EventEmitter = require("events");
var aplayExec = os.platform() === 'darwin' ? 'afplay' : 'aplay';
var Sound = /** @class */ (function (_super) {
    __extends(Sound, _super);
    function Sound(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this) || this;
        _this._stopped = true;
        _this._channel = options.channel;
        return _this;
    }
    // TODO: make this into a promise;
    // TODO: test if file exists
    Sound.prototype.play = function (fileName) {
        var _this = this;
        this._stopped = false;
        // avoid multiple play for the same istance
        if (this._process)
            this._process.kill('SIGTERM');
        console.log(this._channel);
        var args = this._channel ? ["-c " + this._channel] : [];
        if (fileName)
            args = args.concat([fileName]);
        console.log(args);
        this._process = child_process_1.spawn(aplayExec, args);
        this._process.on('exit', function (code, sig) {
            _this._stopped = true;
            if (code !== null && sig === null)
                _this.emit('complete');
        });
        return this;
    };
    Sound.prototype.stop = function () {
        if (this._process) {
            this._stopped = true;
            this._process.kill('SIGTERM');
            this.emit('stop');
        }
        return this;
    };
    Sound.prototype.pause = function () {
        if (this._process) {
            if (this._stopped)
                return this;
            this._process.kill('SIGSTOP');
            this.emit('pause');
        }
        return this;
    };
    Sound.prototype.resume = function () {
        if (this._process) {
            if (this._stopped)
                return this.play();
            this._process.kill('SIGCONT');
            this.emit('resume');
        }
        return this;
    };
    Sound.prototype.setChannel = function (ch) {
        this._channel = ch;
        return this;
    };
    return Sound;
}(EventEmitter));
exports.default = Sound;
// autonomous execution: node node-aplay.js my-song.wav
if (require.main === module) {
    var player = new Sound();
    player.play(process.argv[2]);
}
